Grant

Struct Grant 

pub struct Grant {
    pub graph: String,
    pub role: Role,
}
A per-graph access grant.

When an identity has grants, it can only access the listed graphs at the specified role level. An identity with no grants has unrestricted access (governed only by its top-level roles).

Fields

graph: String

The graph name this grant applies to.

role: Role

The maximum role level for this graph.

Implementations

Source

impl Grant

pub fn new(graph: impl Into<String>, role: Role) -> Self

Creates a new grant for the given graph and role.