pub struct CdcMemory {
pub total_bytes: usize,
pub entity_count: usize,
pub event_count: usize,
}Expand description
CDC log memory breakdown.
Default is empty when the cdc feature is disabled.
Fields
total_bytes: usizeTotal estimated CDC memory in bytes.
entity_count: usizeNumber of entities with at least one recorded event.
event_count: usizeTotal number of recorded change events across all entities.
Implementations