pub struct CachingQueryProcessor<P> { /* private fields */ }Expand description
A caching wrapper for the query processor.
This type wraps a query processor and adds caching capabilities. Use this for production deployments where query caching is beneficial.
Implementations
Sourceimpl<P> CachingQueryProcessor<P>
impl<P> CachingQueryProcessor<P>
Sourcepub fn new(processor: P, cache: QueryCache) -> Self
pub fn new(processor: P, cache: QueryCache) -> Self
Creates a new caching processor.
Sourcepub fn with_default_cache(processor: P) -> Self
pub fn with_default_cache(processor: P) -> Self
Creates a new caching processor with default cache settings.
Sourcepub fn cache(&self) -> &QueryCache
pub fn cache(&self) -> &QueryCache
Returns a reference to the cache.
Sourcepub fn stats(&self) -> CacheStats
pub fn stats(&self) -> CacheStats
Returns cache statistics.
Sourcepub fn clear_cache(&self)
pub fn clear_cache(&self)
Clears the cache.