#[non_exhaustive]pub enum TripleComponent {
Variable(String),
Iri(String),
Literal(Value),
LangLiteral {
value: String,
lang: String,
},
BlankNode(String),
}Expand description
A component of a triple pattern.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Variable(String)
A variable to bind.
Iri(String)
A constant IRI.
Literal(Value)
A constant literal value.
LangLiteral
A language-tagged string literal (RDF rdf:langString).
Carries the lexical value and the BCP47 language tag separately so that the tag survives the translator to planner to RDF store round-trip.
BlankNode(String)
A blank node with a scoped label (used in INSERT DATA).
Implementations
Sourceimpl TripleComponent
impl TripleComponent
Sourcepub fn as_variable(&self) -> Option<&str>
pub fn as_variable(&self) -> Option<&str>
Returns the variable name if this component is a Variable, or None.