pub fn substitute_params(
plan: &mut LogicalPlan,
params: &QueryParams,
) -> Result<()>Expand description
Substitutes parameters in a logical plan with their values.
Errors
Returns an error if a referenced parameter is not found in params.