pub struct ProjectionSpec { /* private fields */ }Expand description
Defines which nodes and edges are included in a projection.
Implementations
Sourceimpl ProjectionSpec
impl ProjectionSpec
Sourcepub fn new() -> ProjectionSpec
pub fn new() -> ProjectionSpec
Creates an empty spec (all nodes, all edges).
Sourcepub fn with_node_labels(
self,
labels: impl IntoIterator<Item = impl Into<String>>,
) -> ProjectionSpec
pub fn with_node_labels( self, labels: impl IntoIterator<Item = impl Into<String>>, ) -> ProjectionSpec
Restricts the projection to nodes with any of these labels.
Sourcepub fn with_edge_types(
self,
types: impl IntoIterator<Item = impl Into<String>>,
) -> ProjectionSpec
pub fn with_edge_types( self, types: impl IntoIterator<Item = impl Into<String>>, ) -> ProjectionSpec
Restricts the projection to edges with any of these types.