pub struct Grant {
pub graph: String,
pub role: Role,
}Expand description
A per-graph access grant.
When an identity has grants, it can only access the listed graphs at the specified role level. An identity with no grants has unrestricted access (governed only by its top-level roles).
Fields
graph: StringThe graph name this grant applies to.
role: RoleThe maximum role level for this graph.
Implementations