SchemaCatalog

Struct SchemaCatalog 

pub struct SchemaCatalog { /* private fields */ }
Schema constraints and type definitions.

Implementations

Source

impl SchemaCatalog

pub fn register_node_type( &self, def: NodeTypeDefinition, ) -> Result<(), CatalogError>

Registers a new node type definition.

pub fn register_or_replace_node_type(&self, def: NodeTypeDefinition)

Registers or replaces a node type definition.

pub fn drop_node_type(&self, name: &str) -> Result<(), CatalogError>

Drops a node type definition by name.

pub fn get_node_type(&self, name: &str) -> Option<NodeTypeDefinition>

Gets a node type definition by name.

pub fn resolved_node_type(&self, name: &str) -> Option<NodeTypeDefinition>

Gets a resolved node type with inherited properties and constraints from parents.

Walks the parent chain depth-first, collecting properties and constraints. Detects cycles via a visited set. Child properties override parent ones with the same name.

pub fn all_node_types(&self) -> Vec<String>

Returns all registered node type names.

pub fn all_node_type_defs(&self) -> Vec<NodeTypeDefinition>

Returns all registered node type definitions.

pub fn register_edge_type( &self, def: EdgeTypeDefinition, ) -> Result<(), CatalogError>

Registers a new edge type definition.

pub fn register_or_replace_edge_type(&self, def: EdgeTypeDefinition)

Registers or replaces an edge type definition.

pub fn drop_edge_type(&self, name: &str) -> Result<(), CatalogError>

Drops an edge type definition by name.

pub fn get_edge_type(&self, name: &str) -> Option<EdgeTypeDefinition>

Gets an edge type definition by name.

pub fn all_edge_types(&self) -> Vec<String>

Returns all registered edge type names.

pub fn all_edge_type_defs(&self) -> Vec<EdgeTypeDefinition>

Returns all registered edge type definitions.

pub fn register_graph_type( &self, def: GraphTypeDefinition, ) -> Result<(), CatalogError>

Registers a new graph type definition.

pub fn drop_graph_type(&self, name: &str) -> Result<(), CatalogError>

Drops a graph type definition by name.

pub fn get_graph_type(&self, name: &str) -> Option<GraphTypeDefinition>

Gets a graph type definition by name.

pub fn all_graph_types(&self) -> Vec<String>

Returns all registered graph type names.

pub fn all_graph_type_defs(&self) -> Vec<GraphTypeDefinition>

Returns all registered graph type definitions.

pub fn register_schema(&self, name: String) -> Result<(), CatalogError>

Registers a schema namespace.

pub fn drop_schema(&self, name: &str) -> Result<(), CatalogError>

Drops a schema namespace.

pub fn schema_exists(&self, name: &str) -> bool

Checks whether a schema namespace exists.

pub fn schema_names(&self) -> Vec<String>

Returns all registered schema namespace names.

pub fn add_constraint_to_type( &self, label: &str, constraint: TypeConstraint, ) -> Result<(), CatalogError>

Adds a constraint to an existing node type, creating a minimal type if needed.

pub fn alter_node_type_add_property( &self, type_name: &str, property: TypedProperty, ) -> Result<(), CatalogError>

Adds a property to an existing node type.

pub fn alter_node_type_drop_property( &self, type_name: &str, property_name: &str, ) -> Result<(), CatalogError>

Drops a property from an existing node type.

pub fn alter_edge_type_add_property( &self, type_name: &str, property: TypedProperty, ) -> Result<(), CatalogError>

Adds a property to an existing edge type.

pub fn alter_edge_type_drop_property( &self, type_name: &str, property_name: &str, ) -> Result<(), CatalogError>

Drops a property from an existing edge type.

pub fn alter_graph_type_add_node_type( &self, graph_type_name: &str, node_type: String, ) -> Result<(), CatalogError>

Adds a node type to a graph type.

pub fn alter_graph_type_drop_node_type( &self, graph_type_name: &str, node_type: &str, ) -> Result<(), CatalogError>

Drops a node type from a graph type.

pub fn alter_graph_type_add_edge_type( &self, graph_type_name: &str, edge_type: String, ) -> Result<(), CatalogError>

Adds an edge type to a graph type.

pub fn alter_graph_type_drop_edge_type( &self, graph_type_name: &str, edge_type: &str, ) -> Result<(), CatalogError>

Drops an edge type from a graph type.

pub fn register_procedure( &self, def: ProcedureDefinition, ) -> Result<(), CatalogError>

Registers a stored procedure.

pub fn replace_procedure(&self, def: ProcedureDefinition)

Replaces or creates a stored procedure.

pub fn drop_procedure(&self, name: &str) -> Result<(), CatalogError>

Drops a stored procedure.

pub fn get_procedure(&self, name: &str) -> Option<ProcedureDefinition>

Gets a stored procedure by name.

pub fn all_procedure_defs(&self) -> Vec<ProcedureDefinition>

Returns all registered procedure definitions.

pub fn all_graph_type_bindings(&self) -> Vec<(String, String)>

Returns all graph type bindings (graph_name, type_name).