MergeRelationshipOp

Struct MergeRelationshipOp 

pub struct MergeRelationshipOp {
    pub variable: String,
    pub source_variable: String,
    pub target_variable: String,
    pub edge_type: String,
    pub match_properties: Vec<(String, LogicalExpression)>,
    pub on_create: Vec<(String, LogicalExpression)>,
    pub on_match: Vec<(String, LogicalExpression)>,
    pub input: Box<LogicalOperator>,
}
Merge a relationship pattern (match or create between two bound nodes).

MERGE on a relationship tries to find an existing relationship of the given type between the source and target nodes. If found, returns the existing relationship (optionally applying ON MATCH SET). If not found, creates it (optionally applying ON CREATE SET).

Fields

variable: String

Variable to bind the relationship to.

source_variable: String

Source node variable (must already be bound).

target_variable: String

Target node variable (must already be bound).

edge_type: String

Relationship type.

match_properties: Vec<(String, LogicalExpression)>

Properties that must match (used for both matching and creation).

on_create: Vec<(String, LogicalExpression)>

Properties to set on CREATE.

on_match: Vec<(String, LogicalExpression)>

Properties to set on MATCH.

input: Box<LogicalOperator>

Input operator.