pub struct ProjectOp {
pub projections: Vec<Projection>,
pub input: Box<LogicalOperator>,
pub pass_through_input: bool,
}Expand description
Project specific columns.
Fields
projections: Vec<Projection>Columns to project.
input: Box<LogicalOperator>Input operator.
pass_through_input: boolWhen true, all input columns are passed through and the explicit projections are appended as additional output columns. Used by GQL LET clauses which add bindings without replacing the existing scope.