pub struct PreparedCommit<'a> { /* private fields */ }Expand description
A transaction that has been validated and is ready to commit.
Created by Session::prepare_commit. The mutable borrow on the session
prevents any concurrent operations while the commit is pending.
If dropped without calling commit or abort,
the transaction is automatically rolled back.
Implementations
Sourceimpl<'a> PreparedCommit<'a>
impl<'a> PreparedCommit<'a>
Sourcepub fn info(&self) -> &CommitInfo
pub fn info(&self) -> &CommitInfo
Returns the commit info (mutation summary).
Sourcepub fn set_metadata(&mut self, key: impl Into<String>, value: impl Into<String>)
pub fn set_metadata(&mut self, key: impl Into<String>, value: impl Into<String>)
Attaches metadata to this commit.
Metadata is available for logging, auditing, or CDC consumers.